componenttools.replace_components_with_children_of_components
=============================================================

.. autofunction:: abjad.tools.componenttools.replace_components_with_children_of_components.replace_components_with_children_of_components
